\name{coxph.sim}
\alias{coxph.sim}
\title{Bootstrap test on a coefficient based on a reference censoring model}
\description{
 Performs the hypothesis testing \eqn{H_0: \psi=value}{H0: psi=value}, using parametric bootstrap
 based on a reference censoring model.
}
\usage{
coxph.sim(coxph.obj, psi, ind.psi, R = 10000, trace=TRUE)
}
\arguments{
  \item{coxph.obj}{
   an object produced by fitting a PH model with coxph(). 
 }
  \item{psi}{ 
   the values of the parameter of interest under testing.
}
  \item{ind.psi}{
   the column index of the interest parameter covariate  in the design matrix. The latter can be obtained by
            \code{model.matrix(coxph.obj)[,-1]}.
 }
  \item{R}{ 
   number of boostrap trials for computing the P-value. The default is \code{10000}.  
 }
  \item{trace}{ 
   if \code{TRUE}, keeps trace of the state of computation, and plots an histogram of the simulated values of \eqn{r}{r}. The
           default is \code{TRUE}.
} 
}
\details{
  The current version supports  only right-censoring without stratification, and it implements uniform resampling from the risk set 
  for the units to be censored.
  No check is made on  coxph.obj, and passing coxph objects created with left-censored data, interval data or counting process data 
  will produce uncorrect results.
}
\value{
  a list summarising the test 
  \item{r.obs }{ observed value of \eqn{r}{r}}
  \item{r.sim }{ vector of simulated values of \eqn{r}{r}}
}

\references{Pierce, D.A, and Bellio, R. (2015). "Beyond first-order asymptotics for Cox regression". \emph{Bernoulli} 21, 401-419.}

\author{Ruggero Bellio, Donald A. Pierce}

\examples{
library(survival)
data(veteran)
## Select celltype==smallcell
vet2<- veteran[veteran$celltype=="smallcell",]
## Model fit 
fit <- coxph(Surv(time,status) ~ age + trt + karno + diagtime + prior, data = vet2)
summary(fit)
## Testing treatment effect
obj <- coxph.sim(fit, psi=0, ind.psi=2, R=10000)
## Right-sided P-value
(sum(obj$r.sim>=obj$r.obs)+1)/(10000+1)
}
\keyword{survival}

